;**;***********************************************************************
;*              MASS-DIMM controller
;*              High voltage, control light, viewer illumination
;*              Circuit diagrams:       mass_dimm.sch
;*              Circuit boards:         mass_dimm.pcb
;*              Last modification:      15.08.03
;*********************************************************************
;*              Device and microprogramm identification
;***********************************************************************
                                        ; Date of the programming;
.equ    _day=          15
.equ    _year=          3
.equ    _month=         8
                                        ; Device code
.equ    _author=        0
.equ    _group=         8               ; Device group
.equ    _device=        1               ; Device serial number

.equ    pdate=          _year*512+_month*32+_day
.equ    iddev=          _author*4096+_group*256+_device

;***********************************************************************
;*              Microcontroller input/output definitions
;***********************************************************************
                                        ; Port D
.equ    RX=             PD0             ; UART Input
.equ    TX=             PD1             ; UART Output
.equ    RXI=            PD2             ; Line monitor input
.equ    OVER=           PD3             ; Overlight signal input
.equ    STROB=          PD4             ; Integration strob input
.equ    DE=             PD6             ; RS485 transmission enable output
.equ    YELLOW=         PD7             ; Line indicator lED output
.equ    DDIRECT= 0b11000010
.equ    DMASK=   0b10011111
                                         ;Port B     (sin)
.equ    LOAD=           PB0             ; Select AD8402 output
.equ    IL_LOAD=        PB1             ; PWM output for illumination
.equ    MOSI=           PB3             ; Data for AD8402 loading
.equ    SCK=            PB5             ; SCK for AD8402 loading
.equ    BDIRECT= 0b00101111
.equ    BMASK=   0b00000111
                                         ;Port C     (cos)
.equ    HALL=           PC0             ; Hall sensor input
.equ    SHUTDOWN=       PC2             ; High-voltage shutdown output
.equ    CDIRECT= 0b00000100
.equ    CMASK=   0b00000101

;***********************************************************************
;*              Working register definitions
;***********************************************************************
.def    ARGUMENT=       R0
;.def   XXX=            R1
;.def    ABS_POSL=       R2              ; Absolute position, low
;.def    ABS_POSH=       R3              ; Absolute position, high
;.def    ABS_POSS=       R4              ; Absolute position significant
.def    BOTTOM=         R5              ; Timer 2 starting value
.def    CHATTER=        R6              ; Mirror sensor development registr
.def    SREG_COPY=      R7              ; SREG copy register for interrupt handle
.def    AL=             R8
.def    AH=             R9
.def    POINTER=       R10              ; Pointer in Fluxies array
.def    SENSOR=        R11              ; Sensor status registr
.def    RL=            R12
.def    RH=            R13
.def    BYTE_CNT=      R14              ; Packet bytes counter
.def    COUNTS=        R15              ; Temperature measurements counter

.def    STATUS=        R16              ; STATUS register
.def    LINE_CSR=      R17              ; LINE STATUS register
;.def    SPI_EN=        R18              ; SPI enable
.def    TEMP=          R19
.def    TEMP_CNT=      R20
.def    TREG=          R21              ; Temporal register for interrupt handle
.def    RECEIVE=       R22              ; Temporal receiver register
.def    COMMAND=       R22              ; Temporal command register
.def    TRANSMIT=      R23              ; Temporal transmitter register

;.def    COUNTL=        R24              ; Relative motion counter low
;.def    COUNTH=        R25              ; Relative motion counter high

.equ    DIVISOR=         7
.equ    NPARAM=         16
.equ    MAXADRESS=    0x1F
.equ    MAXARGUMENT=  0x0F
.equ    MODIFICATOR=     4

;***********************************************************************
;*              Status registers flags
;***********************************************************************
                                        ; STATUS register
.equ    MIRROR=          7              ; Viewer mirror of axis
.equ    MODULATION=      6              ; Modulation of the control light on
.equ    ILLUM=           5              ; Illumination on
.equ    CONTROL=         4              ; Control light on

.equ    LOCK_HV=         3              ; High voltage locking
.equ    OVERLIGHT=       2              ; Overlight indicator
.equ    SAFETY=          1              ; Safety on (overlight protection on)
.equ    HV_ON=           0              ; High voltage turned on

                                        ; LINE STATUS register
.equ    RECEIVING=       7              ; Packet receiving in progress
.equ    RECV_READY=      6              ; Packet receiving is complete
.equ    LINE_BUSY=       5              ; Line is busy
.equ    FAILURE=         4               ; Transmission failure is detected

.equ    DATA_SENDING=    2              ; Data block is transmitted

;***********************************************************************
;*              Protocol Signals
;***********************************************************************
.equ    ACK= 0x87                       ; Successful receiving of data
.equ    NAK= 0x96                       ; Damaged packet was received
.equ    NOD= 0xA5                       ; Required data are not ready
.equ    ACN= 0xB4                       ; Such a command does not exist
.equ    ACY= 0xC3                       ; Command is successfully received and executed
.equ    ACW= 0xD2                       ; Command can not be executed right now
.equ    SINC=0xE1                       ; Synchronization signal
.equ    DNG= 0xF0                       ; Danger signal

;***********************************************************************
;*              Exchange constants
;***********************************************************************
.equ    NLINE=            4             ; Number of line parameters
.equ    AUX=           0x10             ; Stepper motor controller address
.equ    EXCHANGE_RATE=  115             ; Exchange rate in KBod
.equ    WINDOW=         500             ; Reply window duration (mks)
.equ    DELAY=           25             ; Transmittance switch delay (mks)
.equ    MAXRETRY=        2              ; Maximal number of retries
.equ    freq=         14746             ; Oscillator frequency (cycles/ms)

.equ    scale2=         64              ; Prescaler of line timer, This depends on clock frequency
.equ    fwindow=        (WINDOW*freq/1000/scale2)
.equ    fdelay=         (DELAY*freq/1000/scale2)
.equ    fbottom=        0xff-fwindow
.equ    fswitch=        fbottom+fdelay+1
.equ    fbaudrate=      (freq/EXCHANGE_RATE)/16-1 ;  Max baudrate = -1 => U2X = 1

;***********************************************************************
;*              Functional constants
;***********************************************************************
.equ    scale1=         256             ; Prescaler  of Timer1
.equ    FLONG=           64             ; Frequency of temperature polling (cycles/s)
.equ    fcycle=      freq*1000/64/FLONG
.equ    dillum=         128
.equ    dlight=         128
.equ    dvariation=     128
.equ    dvoltage=       128

;Fuse bites
;ணࠬ஢
; BODEN
; BODLEVEL
; BOOTSZ0
; BOOTSZ1
; CKOPT
; SPIEN
; BLB11
